import { setBlockType } from 'prosemirror-commands';
import { headingAction } from './actions';
import { HeadingAction, headingLevelAttr } from './const';
import { headingRule, hType } from './utils';
import { resetHeading } from './commands';
import { HeadingSpecs } from './HeadingSpecs';
export { headingNodeName, headingType } from './HeadingSpecs';
export { HeadingAction } from './const';
export { hType } from './utils';
export const Heading = (builder, opts) => {
    builder.use(HeadingSpecs, opts);
    builder
        .addKeymap(({ schema }) => {
        const { h1Key, h2Key, h3Key, h4Key, h5Key, h6Key } = opts !== null && opts !== void 0 ? opts : {};
        const cmd4lvl = (level) => setBlockType(hType(schema), { [headingLevelAttr]: level });
        const bindings = { Backspace: resetHeading };
        if (h1Key)
            bindings[h1Key] = cmd4lvl(1);
        if (h2Key)
            bindings[h2Key] = cmd4lvl(2);
        if (h3Key)
            bindings[h3Key] = cmd4lvl(3);
        if (h4Key)
            bindings[h4Key] = cmd4lvl(4);
        if (h5Key)
            bindings[h5Key] = cmd4lvl(5);
        if (h6Key)
            bindings[h6Key] = cmd4lvl(6);
        return bindings;
    })
        .addInputRules(({ schema }) => ({ rules: [headingRule(hType(schema), 6)] }));
    builder
        .addAction(HeadingAction.ToH1, ({ schema }) => headingAction(hType(schema), 1))
        .addAction(HeadingAction.ToH2, ({ schema }) => headingAction(hType(schema), 2))
        .addAction(HeadingAction.ToH3, ({ schema }) => headingAction(hType(schema), 3))
        .addAction(HeadingAction.ToH4, ({ schema }) => headingAction(hType(schema), 4))
        .addAction(HeadingAction.ToH5, ({ schema }) => headingAction(hType(schema), 5))
        .addAction(HeadingAction.ToH6, ({ schema }) => headingAction(hType(schema), 6));
};
